@@ -207,7 +207,8 @@
 	       (script `(h:script (@ (language "javascript")) ,code)))
 	  (set! xhead (append xhead (list script)))))
     (if (or (in? "tmdoc" styles) (in? "tmweb" styles)
-            (in? "mmxdoc" styles) (in? "magix-web" styles))
+            (in? "mmxdoc" styles) (in? "magix-web" styles)
+            (in? "max-web" styles))
 	(set! body (tmhtml-tmdoc-post body)))
     `(h:html
       (h:head
@@ -893,7 +894,9 @@
   ;; in order to disable this suffix change
   (let* ((sdir (string-rindex s #\/))
 	 (sep (string-rindex s #\#)))
-    (cond ((or (string-starts? s "http:") (string-starts? s "ftp:")) s)
+    (cond ((or (string-starts? s "http:")
+               (string-starts? s "https:")
+               (string-starts? s "ftp:")) s)
           ((and sep (or (not sdir) (< sdir sep)))
 	   (string-append (tmhtml-suffix (substring s 0 sep))
 			  (string-drop s sep)))
@@ -1081,16 +1084,18 @@
 (define (tmhtml-png y)
   (let* ((mag (ahash-ref tmhtml-env :mag))
 	 (x (if (or (nstring? mag) (== mag "1")) y
-		`(with "font-size" ,mag ,y)))
+		`(with "magnification" ,mag ,y)))
 	 (l1 (tmhtml-collect-labels y))
 	 (l2 (if (null? l1) l1 (list (car l1)))))
     (with cached (ahash-ref tmhtml-image-cache x)
       (if (not cached)
 	  (receive (name-url name-string) (tmhtml-image-names "png")
 	    ;;(display* x " -> " name-url ", " name-string "\n")
-	    (let* ((extents (print-snippet name-url x))
-		   ;;(pixels (inexact->exact (/ (second extents) 2100)))
-		   (pixels (inexact->exact (/ (second extents) 2000)))
+	    (let* ((extents (print-snippet name-url x #t))
+                   (dpi (string->number (get-preference "printer dpi")))
+                   (den (/ (* dpi 2200.0) 600.0))
+                   ;;(den (/ (* dpi 2000.0) 600.0))
+		   (pixels (inexact->exact (/ (second extents) den)))
 		   (valign (number->htmlstring pixels))
 		   (style (string-append "vertical-align: " valign "px")))
 	      ;;(display* x " -> " extents "\n")
@@ -1373,6 +1378,7 @@
   (list `(h:div (@ (class "tmdoc-license")) ,@(tmhtml (car l)))))
 
 (define (tmhtml-key l)
+  ;; `((h:u (h:tt ,@(tmhtml (tm->stree (tmdoc-key (car l))))))))
   `((h:u (h:tt ,@(tmhtml (car l))))))
 
 (define (tmhtml-tmdoc-bar? y)
@@ -1478,6 +1484,10 @@
   (page-break tmhtml-noop)
   (no-page-break* tmhtml-noop)
   (no-page-break tmhtml-noop)
+  (no-break-here* tmhtml-noop)
+  (no-break-here tmhtml-noop)
+  (no-break-start tmhtml-noop)
+  (no-break-end tmhtml-noop)
   (new-page* tmhtml-noop)
   (new-page tmhtml-noop)
   (new-dpage* tmhtml-noop)
